# tird: this is random data

Tool for encrypting and hiding files.

## Usage

Just run the script:
```
$ tird
Select the action to take
0 - exit
1 - get info
2 - encrypt file
3 - decrypt file
4 - encrypt and hide file
5 - decrypt and unhide file
6 - hide file (without  encryption)
7 - unhide file (without decryprion)
8 - create file with random data
9 - overwrite file with random or specific bytes
:
```

## Requirements

- Python >= 3.6
